---
name: Documentation issue
about: Use this template to report an issue you've found with the documentation.
title: ''
labels: 't: bug report, c: documentation, s: unanswered'
assignees: ''

---

<!--

Welcome!  Unfortunately not all documentation is perfect, and if you're opening
a documentation issue we are interested in fixing it.  Please fill out the
template below so that we can solve the problem more quickly; or, alternately,
open a PR with a fix, if you like.

-->

#### Problem location

<!-- Link to incorrect website or location of source file with bad
documentation. -->

#### Description of problem

<!-- Tell us what is wrong with the documentation so we can fix it. -->
